==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: it\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Linea"

, "Caller Id"
: "Numero chiamante"

, "Start"
: "Avvia"

, "Connected"
: "Connesso"

, "Disconnected"
: "Disconnesso"

, "Duration"
: "Durata"

, "Ringing"
: "Squillo"

, "Direction"
: "Direzione"

, "Source"
: "Sorgente"

, "Destination"
: "Destinazione"

, "Phone"
: ""

, "Phones"
: "Telefoni"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Numero"

, "Cancel"
: "Cancella"

, "Dial"
: "Componi"

, "Error"
: "Errore"

, "Not possible to dial."
: "Impossibile comporre."

, "Edit phone settings"
: "Modifica le impostazioni del telefono"

, "Dial number"
: "Componi il numero"

, "Initiate a new outgoing call"
: "Inizia una nuova chiamata"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Chiama contatto"

, "Work"
: "Lavoro"

, "Home"
: "Abitazione"

, "Cell"
: "Cellulare"

, "Cell private"
: "Cellulare privato"

, "Incoming call"
: "Chiamata in arrivo"

, "Outgoing call"
: "Chiamata in uscita"

, "unknown number"
: "numero sconosciuto"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Chiamata in arrivo"

, "Outgoing call"
: "Chiamata in uscita"

, "unknown number"
: "numero sconosciuto"

, "Phone"
: ""

, "Line"
: "Linea"

, "Number"
: "Numero"

, "Cancel"
: "Cancella"

, "Dial"
: "Componi"

, "Error"
: "Errore"

, "Not possible to dial."
: "Impossibile comporre."

, "Call contact"
: "Chiama contatto"

, "Work"
: "Lavoro"

, "Home"
: "Abitazione"

, "Cell"
: "Cellulare"

, "Cell private"
: "Cellulare privato"

, "Edit phone settings"
: "Modifica le impostazioni del telefono"

, "Dial number"
: "Componi il numero"

, "Initiate a new outgoing call"
: "Inizia una nuova chiamata"

, "Phones"
: "Telefoni"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Numero chiamante"

, "Start"
: "Avvia"

, "Connected"
: "Connesso"

, "Disconnected"
: "Disconnesso"

, "Duration"
: "Durata"

, "Ringing"
: "Squillo"

, "Direction"
: "Direzione"

, "Source"
: "Sorgente"

, "Destination"
: "Destinazione"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
